summaryrefslogtreecommitdiffstats
path: root/kio/kfile/knotifydialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kfile/knotifydialog.cpp')
-rw-r--r--kio/kfile/knotifydialog.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kio/kfile/knotifydialog.cpp b/kio/kfile/knotifydialog.cpp
index 3ed69ec71..9e370643f 100644
--- a/kio/kfile/knotifydialog.cpp
+++ b/kio/kfile/knotifydialog.cpp
@@ -65,7 +65,7 @@ enum
};
//
// I don't feel like subclassing KComboBox and tqfind ways to insert that into
// the .ui file...
//
namespace KNotify
@@ -130,7 +130,7 @@ namespace KNotify
protected:
virtual void maybeTip ( const TQPoint& p )
{
- TQHeader *header = static_cast<TQHeader*>( tqparentWidget() );
+ TQHeader *header = static_cast<TQHeader*>( parentWidget() );
int section = 0;
if ( header->orientation() == Horizontal )
@@ -181,7 +181,7 @@ KNotifyDialog::~KNotifyDialog()
void KNotifyDialog::addApplicationEvents( const char *appName )
{
addApplicationEvents( TQString::fromUtf8( appName ) +
- TQString::tqfromLatin1( "/eventsrc" ) );
+ TQString::fromLatin1( "/eventsrc" ) );
}
void KNotifyDialog::addApplicationEvents( const TQString& path )
@@ -514,7 +514,7 @@ void KNotifyWidget::updatePixmaps( ListViewItem *item )
void KNotifyWidget::addVisibleApp( Application *app )
{
- if ( !app || (m_visibleApps.tqfindRef( app ) != -1) )
+ if ( !app || (m_visibleApps.findRef( app ) != -1) )
return;
m_visibleApps.append( app );
@@ -830,8 +830,8 @@ void KNotifyWidget::save()
// "/opt/kde3/share/apps/kwin/eventsrc"
TQString KNotifyWidget::makeRelative( const TQString& fullPath )
{
- int slash = fullPath.tqfindRev( '/' ) - 1;
- slash = fullPath.tqfindRev( '/', slash );
+ int slash = fullPath.findRev( '/' ) - 1;
+ slash = fullPath.findRev( '/', slash );
if ( slash < 0 )
return TQString::null;
@@ -861,7 +861,7 @@ void KNotifyWidget::openSoundDialog( KURLRequester *requester )
<< "audio/x-adpcm";
fileDialog->setMimeFilter( filters );
// tqfind the first "sound"-resource that tqcontains files
const Application *app = currentEvent()->application();
TQStringList soundDirs =
KGlobal::dirs()->findDirs("data", app->appName() + "/sounds");
@@ -918,7 +918,7 @@ void KNotifyWidget::playSound()
if (!KIO::NetAccess::exists( m_soundPath->url(), true, 0 )) {
bool foundSound=false;
// tqfind the first "sound"-resource that tqcontains files
const Application *app = currentEvent()->application();
TQStringList soundDirs = KGlobal::dirs()->findDirs("data", app->appName() + "/sounds");
soundDirs += KGlobal::dirs()->resourceDirs( "sound" );
@@ -1001,17 +1001,17 @@ void KNotifyWidget::enableAll( int what, bool enable )
Application::Application( const TQString &path )
{
TQString config_file = path;
- config_file[config_file.tqfind('/')] = '.';
+ config_file[config_file.find('/')] = '.';
m_events = 0L;
config = new KConfig(config_file, false, false);
kc = new KConfig(path, true, false, "data");
- kc->setGroup( TQString::tqfromLatin1("!Global!") );
- m_icon = kc->readEntry(TQString::tqfromLatin1("IconName"),
- TQString::tqfromLatin1("misc"));
- m_description = kc->readEntry( TQString::tqfromLatin1("Comment"),
+ kc->setGroup( TQString::fromLatin1("!Global!") );
+ m_icon = kc->readEntry(TQString::fromLatin1("IconName"),
+ TQString::fromLatin1("misc"));
+ m_description = kc->readEntry( TQString::fromLatin1("Comment"),
i18n("No description available") );
- int index = path.tqfind( '/' );
+ int index = path.find( '/' );
if ( index >= 0 )
m_appname = path.left( index );
else
@@ -1070,10 +1070,10 @@ void Application::reloadEvents( bool revertToDefaults )
Event *e = 0L;
- TQString global = TQString::tqfromLatin1("!Global!");
- TQString default_group = TQString::tqfromLatin1("<default>");
- TQString name = TQString::tqfromLatin1("Name");
- TQString comment = TQString::tqfromLatin1("Comment");
+ TQString global = TQString::fromLatin1("!Global!");
+ TQString default_group = TQString::fromLatin1("<default>");
+ TQString name = TQString::fromLatin1("Name");
+ TQString comment = TQString::fromLatin1("Comment");
TQStringList conflist = kc->groupList();
TQStringList::ConstIterator it = conflist.begin();
@@ -65,7 +65,7 @@ enum
};
//
-// I don't feel like subclassing KComboBox and tqfind ways to insert that into
+// I don't feel like subclassing KComboBox and find ways to insert that into
// the .ui file...
//
@@ -861,7 +861,7 @@ void KNotifyWidget::openSoundDialog( KURLRequester *requester )
<< "audio/x-adpcm";
fileDialog->setMimeFilter( filters );
- // tqfind the first "sound"-resource that tqcontains files
+ // find the first "sound"-resource that contains files
const Application *app = currentEvent()->application();
TQStringList soundDirs =
@@ -918,7 +918,7 @@ void KNotifyWidget::playSound()
if (!KIO::NetAccess::exists( m_soundPath->url(), true, 0 )) {
bool foundSound=false;
- // tqfind the first "sound"-resource that tqcontains files
+ // find the first "sound"-resource that contains files
const Application *app = currentEvent()->application();
TQStringList soundDirs = KGlobal::dirs()->findDirs("data", app->appName() + "/sounds");